@@ -212,10 +212,12 @@ class Leg(object):
             self.__stretchangle = self.__leg_minangle
         self.__currentangle = self.__stretchangle
 
+
     def setswing(self):
         """ DEPRICATED - Use Swing instead"""
         print("This function is depricated use swing instead")
 
+
     def swing(self):
         """
         Sets the limb to its swing position, which is 45 degrees - halfway
@@ -261,11 +263,11 @@ class Leg(object):
         print(self.__channel)
         print(self.name)
 
-    def setangle(self, angle):
+    def setangle(self, value):
         """
         DEPRICATED METHOD - USE .angle
         """
-        print(f"This method is depricated - use .angle instead to set angle to {angle}")
+        print(f"This method is depricated - use .angle instead to set angle to {value}")
 
     @angle.setter
     def angle(self, user_angle):
@@ -460,7 +462,7 @@ class SmarsRobot(object):
         for limb in range(0, 4):
             self.__feet[limb].down()
             time.sleep(SLEEP_COUNT)
-            self.__legs[limb].setswing()
+            self.__legs[limb].swing()
             time.sleep(SLEEP_COUNT)
             self.__feet[limb].up()
             time.sleep(SLEEP_COUNT)
